import com.j256.ormlite.dao.Dao;
import com.j256.ormlite.dao.DaoManager;
import com.j256.ormlite.jdbc.JdbcConnectionSource;
import com.j256.ormlite.support.ConnectionSource;

import java.sql.SQLDataException;
import java.sql.SQLException;
import java.util.Scanner;

public class AccountApp {

    // we are using a MySQl database
    private final static String DATABASE_URL = "jdbc:mysql://localhost:3306/orm_lab?useUnicode=true";
    private final static String YOURUSERNAME = "root";
    private final static String YOURPASSWORD = "";

    private Dao<Account, Integer> accountDao;
    private Console console = new Console();

    public static void main(String[] args) throws Exception {
        // turn our static method into an instance of Main
        new AccountApp().doMain(args);
    }

    private void doMain(String[] args) throws Exception {
        ConnectionSource connectionSource = null;
        try {
            // create our data-source for the database
            connectionSource = new JdbcConnectionSource(DATABASE_URL, YOURUSERNAME, YOURPASSWORD);
            // setup our  DAOs
            setupDao(connectionSource);
            // read, write and delete some data
            processData();

            System.out.println("\n\nGoodbye!\n\n");
        } finally {
            // destroy the data source which should close underlying connections
            if (connectionSource != null) {
                connectionSource.close();
            }
        }
    }

    /**
     * Read and write some example data.
     */
    private void processData() throws Exception {
        boolean flag = true;
        AcctService acctService = new AcctService(accountDao);

        while (flag) {
            String input = console.inputMenu();

            switch (input) {
                case "CREATE":
                    acctService.createAccount();
                    console.successMessage(input);
                    break;
                case "READ":
                    acctService.readAccounts(acctService.read());
                    console.successMessage(input);
                    break;
                case "UPDATE":
                    acctService.updateAccount();
                    console.successMessage(input);
                    break;
                case "DELETE":
                    acctService.delete(console.deleteAccount());
                    console.successMessage(input);
                    break;
                case "QUIT":
                    flag = false;
                    break;
                default:
                    console.errorMessage();
                    break;
            }

        }
    }

    /**
     * Setup our  DAOs
     */
    private void setupDao(ConnectionSource connectionSource) throws Exception {

        accountDao = DaoManager.createDao(connectionSource, Account.class);

    }
}
